WITH unified_orgs AS (
    -- Get orgs with MDR Unified Console enabled yesterday.
    SELECT
    distinct(org_key),
        org_name
        FROM "product_metrics"."cbc_orgs_config"
        WHERE array_join(transform(flags_enabled, x -> if(x.feature = 'tempMDRUnifiedConsole' and x.enabled = true, 'true', null)), ',') LIKE '%true%' and CAST(sh_date as date) = current_date - interval '1' day
),
mdr_alerts AS (
    -- Get alert in last month from orgs with MDR Unified Console enabled yesterday.
    SELECT * FROM mdr_alerts_last_month
    WHERE org_key IN (select org_key from unified_orgs)
),
likely_ttr AS (
    -- Get TTR from likely alerts for for each day.
    SELECT
        org_key,
        create_date,
        avg(full_ttr) as likely_avg_ttr,
        COUNT(*) as likely_count
        FROM mdr_alerts
        WHERE determination = 'Likely Threat'
        GROUP BY org_key, create_date
),
mdr_ttr AS (
    -- Get TTR from MDR alerts for each day.
    SELECT
        org_key,
        create_date,
        avg(full_ttr) as mdr_avg_ttr,
        COUNT(*) as mdr_count
        FROM mdr_alerts
        WHERE severity >= 5
        GROUP BY org_key, create_date
),
likely_alert_stat AS (
    -- Get alert severity distribution from likely alerts for each day.
    SELECT
        org_key,
        create_date,
        COUNT(CASE WHEN severity = 5 THEN 1 END) AS likely_alert_5,
        COUNT(CASE WHEN severity = 6 THEN 1 END) AS likely_alert_6,
        COUNT(CASE WHEN severity = 7 THEN 1 END) AS likely_alert_7,
        COUNT(CASE WHEN severity = 8 THEN 1 END) AS likely_alert_8,
        COUNT(CASE WHEN severity = 9 THEN 1 END) AS likely_alert_9,
        COUNT(CASE WHEN severity = 10 THEN 1 END) AS likely_alert_10
    FROM mdr_alerts
    WHERE determination = 'Likely Threat'
    GROUP BY org_key, create_date
),
mdr_alert_stat AS (
    -- Get alert severity distribution from MDR alerts for each day.
    SELECT
        org_key,
        create_date,
        COUNT(CASE WHEN severity = 5 THEN 1 END) AS mdr_alert_5,
        COUNT(CASE WHEN severity = 6 THEN 1 END) AS mdr_alert_6,
        COUNT(CASE WHEN severity = 7 THEN 1 END) AS mdr_alert_7,
        COUNT(CASE WHEN severity = 8 THEN 1 END) AS mdr_alert_8,
        COUNT(CASE WHEN severity = 9 THEN 1 END) AS mdr_alert_9,
        COUNT(CASE WHEN severity = 10 THEN 1 END) AS mdr_alert_10
    FROM mdr_alerts
    WHERE severity >= 5
    GROUP BY org_key, create_date
),
likely_app_freq AS (
    -- Get rank of application and its name from likely alerts for each day.
    SELECT
        org_key,
        create_date,
        MAX(CASE WHEN app_rank = 1 THEN app_name END) AS likely_app_1,
        MAX(CASE WHEN app_rank = 1 THEN app_count END) AS likely_app_1_cnt,
        MAX(CASE WHEN app_rank = 2 THEN app_name END) AS likely_app_2,
        MAX(CASE WHEN app_rank = 2 THEN app_count END) AS likely_app_2_cnt,
        MAX(CASE WHEN app_rank = 3 THEN app_name END) AS likely_app_3,
        MAX(CASE WHEN app_rank = 3 THEN app_count END) AS likely_app_3_cnt,
        MAX(CASE WHEN app_rank = 4 THEN app_name END) AS likely_app_4,
        MAX(CASE WHEN app_rank = 4 THEN app_count END) AS likely_app_4_cnt,
        MAX(CASE WHEN app_rank = 5 THEN app_name END) AS likely_app_5,
        MAX(CASE WHEN app_rank = 5 THEN app_count END) AS likely_app_5_cnt,
        MAX(CASE WHEN app_rank = 6 THEN app_name END) AS likely_app_6,
        MAX(CASE WHEN app_rank = 6 THEN app_count END) AS likely_app_6_cnt
    FROM (
        SELECT
            org_key,
            create_date,
            app_name,
            COUNT(*) AS app_count,
            ROW_NUMBER() OVER (PARTITION BY org_key, create_date ORDER BY COUNT(*) DESC) AS app_rank
        FROM mdr_alerts
        WHERE determination = 'Likely Threat'
        GROUP BY org_key, create_date, app_name
    ) ranked_apps
    WHERE app_rank <= 6
    GROUP BY org_key, create_date
),
mdr_app_freq AS (
    -- Get rank of application and its name from MDR alerts for each day.
    SELECT
        org_key,
        create_date,
        MAX(CASE WHEN app_rank = 1 THEN app_name END) AS mdr_app_1,
        MAX(CASE WHEN app_rank = 1 THEN app_count END) AS mdr_app_1_cnt,
        MAX(CASE WHEN app_rank = 2 THEN app_name END) AS mdr_app_2,
        MAX(CASE WHEN app_rank = 2 THEN app_count END) AS mdr_app_2_cnt,
        MAX(CASE WHEN app_rank = 3 THEN app_name END) AS mdr_app_3,
        MAX(CASE WHEN app_rank = 3 THEN app_count END) AS mdr_app_3_cnt,
        MAX(CASE WHEN app_rank = 4 THEN app_name END) AS mdr_app_4,
        MAX(CASE WHEN app_rank = 4 THEN app_count END) AS mdr_app_4_cnt,
        MAX(CASE WHEN app_rank = 5 THEN app_name END) AS mdr_app_5,
        MAX(CASE WHEN app_rank = 5 THEN app_count END) AS mdr_app_5_cnt,
        MAX(CASE WHEN app_rank = 6 THEN app_name END) AS mdr_app_6,
        MAX(CASE WHEN app_rank = 6 THEN app_count END) AS mdr_app_6_cnt
    FROM (
        SELECT
            org_key,
            create_date,
            app_name,
            COUNT(*) AS app_count,
            ROW_NUMBER() OVER (PARTITION BY org_key, create_date ORDER BY COUNT(*) DESC) AS app_rank
        FROM mdr_alerts
        WHERE severity >= 5
        GROUP BY org_key, create_date, app_name
    ) ranked_apps
    WHERE app_rank <= 6
    GROUP BY org_key, create_date
),
likely_dev_freq AS (
        -- Get rank of device and its name from likely alerts for each day.
        SELECT
        org_key,
        create_date,
        MAX(CASE WHEN dev_rank = 1 THEN device_name END) AS likely_dev_1,
        MAX(CASE WHEN dev_rank = 1 THEN device_cnt END) AS likely_dev_1_cnt,
        MAX(CASE WHEN dev_rank = 2 THEN device_name END) AS likely_dev_2,
        MAX(CASE WHEN dev_rank = 2 THEN device_cnt END) AS likely_dev_2_cnt,
        MAX(CASE WHEN dev_rank = 3 THEN device_name END) AS likely_dev_3,
        MAX(CASE WHEN dev_rank = 3 THEN device_cnt END) AS likely_dev_3_cnt,
        MAX(CASE WHEN dev_rank = 4 THEN device_name END) AS likely_dev_4,
        MAX(CASE WHEN dev_rank = 4 THEN device_cnt END) AS likely_dev_4_cnt,
        MAX(CASE WHEN dev_rank = 5 THEN device_name END) AS likely_dev_5,
        MAX(CASE WHEN dev_rank = 5 THEN device_cnt END) AS likely_dev_5_cnt,
        MAX(CASE WHEN dev_rank = 6 THEN device_name END) AS likely_dev_6,
        MAX(CASE WHEN dev_rank = 6 THEN device_cnt END) AS likely_dev_6_cnt
    FROM (
        SELECT
            org_key,
            create_date,
            device_name,
            COUNT(*) AS device_cnt,
            ROW_NUMBER() OVER (PARTITION BY org_key, create_date ORDER BY COUNT(*) DESC) AS dev_rank
        FROM mdr_alerts
        WHERE determination = 'Likely Threat'
        GROUP BY org_key, create_date, device_name
    ) ranked_apps
    WHERE dev_rank <= 6
    GROUP BY org_key, create_date
),
mdr_dev_freq AS (
        -- Get rank of device and its name from MDR alerts for each day.
        SELECT
        org_key,
        create_date,
        MAX(CASE WHEN dev_rank = 1 THEN device_name END) AS mdr_dev_1,
        MAX(CASE WHEN dev_rank = 1 THEN device_cnt END) AS mdr_dev_1_cnt,
        MAX(CASE WHEN dev_rank = 2 THEN device_name END) AS mdr_dev_2,
        MAX(CASE WHEN dev_rank = 2 THEN device_cnt END) AS mdr_dev_2_cnt,
        MAX(CASE WHEN dev_rank = 3 THEN device_name END) AS mdr_dev_3,
        MAX(CASE WHEN dev_rank = 3 THEN device_cnt END) AS mdr_dev_3_cnt,
        MAX(CASE WHEN dev_rank = 4 THEN device_name END) AS mdr_dev_4,
        MAX(CASE WHEN dev_rank = 4 THEN device_cnt END) AS mdr_dev_4_cnt,
        MAX(CASE WHEN dev_rank = 5 THEN device_name END) AS mdr_dev_5,
        MAX(CASE WHEN dev_rank = 5 THEN device_cnt END) AS mdr_dev_5_cnt,
        MAX(CASE WHEN dev_rank = 6 THEN device_name END) AS mdr_dev_6,
        MAX(CASE WHEN dev_rank = 6 THEN device_cnt END) AS mdr_dev_6_cnt
    FROM (
        SELECT
            org_key,
            create_date,
            device_name,
            COUNT(*) AS device_cnt,
            ROW_NUMBER() OVER (PARTITION BY org_key, create_date ORDER BY COUNT(*) DESC) AS dev_rank
        FROM mdr_alerts
        WHERE severity >= 5
        GROUP BY org_key, create_date, device_name
    ) ranked_apps
    WHERE dev_rank <= 6
    GROUP BY org_key, create_date
),
assets AS (
        SELECT
        orgs.org_key,
        environment,
        org_id,
        a.*
    FROM (
        SELECT
            DATE(sh_date) as create_date,
            environment,
            org_id,
            registered,
            registered_total_active,
            registered_active_windows,
            registered_active_mac,
            registered_active_linux
            FROM "product_metrics"."cbc_device_stats_cleansed"
            where CAST(sh_date AS DATE) >= date_trunc('month', current_date - interval '1' month)
            and CAST(sh_date AS DATE) <= (date_trunc('month', current_date) - interval '1' day)
        ) AS a
        LEFT JOIN product_metrics.cbc_orgs orgs
        using(environment, org_id)
),
policy AS (
    SELECT org_key,
           CAST(SUM(CASE WHEN quarantine_permission THEN devices_count ELSE 0 END) AS double) / CAST(SUM(devices_count) AS double) AS ratio_quarantine,
           CAST(SUM(CASE WHEN policy_modification_permission THEN devices_count ELSE 0 END) AS double) / CAST(SUM(devices_count) AS double) AS ratio_policy_modification
    FROM product_metrics.pum_policy_report t
    WHERE t.sh_date = (SELECT max(sh_date) FROM product_metrics.pum_policy_report where org_key = t.org_key)
    GROUP BY t.org_key
)
-- Group alert statistic data by org_key and create_date
SELECT
    org_key,
    unified_orgs.org_name,
    create_date,
    likely_alert_stat.*,
    mdr_alert_stat.*,
    COALESCE(lt.likely_avg_ttr, 0) as likely_avg_ttr,
    COALESCE(lt.likely_count, 0) as likely_count,
    COALESCE(mt.mdr_avg_ttr, 0) as mdr_avg_ttr,
    COALESCE(mt.mdr_count, 0) as mdr_count,
    likely_app.*,
    mdr_app_freq.*,
    likely_dev.*,
    mdr_dev_freq.*,
    assets.*
FROM unified_orgs
LEFT JOIN mdr_alert_stat using (org_key)
LEFT JOIN likely_alert_stat using (org_key, create_date)
LEFT JOIN likely_ttr lt using (org_key, create_date)
LEFT JOIN mdr_ttr mt using (org_key, create_date)
LEFT JOIN likely_app_freq likely_app using (org_key, create_date)
LEFT JOIN mdr_app_freq using (org_key, create_date)
LEFT JOIN likely_dev_freq likely_dev using (org_key, create_date)
LEFT JOIN mdr_dev_freq using (org_key, create_date)
LEFT JOIN assets using (org_key, create_date)
LEFT JOIN policy using (org_key)